==> tuia-advert-center-api-1.5.9-20180808.064513-17-sources.jar: cn/com/duiba/tuia/core/api/dto/AccountCheckRecordDto.java <==
/**
 * 文件名： AccountCheckRecordDO.java 此类描述的是： 作者: sunjiangrong 创建时间: 2016年4月7日 下午3:19:01
 */
package cn.com.duiba.tuia.core.api.dto;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * <一句话功能描述> <功能详细描述>
 * 
 * @author: sunjiangrong
 * @创建时间: 2016年4月7日 下午3:19:01
 * @version:
 */
public class AccountCheckRecordDto extends BaseDto {

    private static final long serialVersionUID = 5143933030739357226L;

    /** 审核通过 */
    public static final int   CHECK_PASS       = 0;
    /** 审核不通过 */
    public static final int   CHECK_REFUSE     = 1;
    /** 冻结 */
    public static final int   FREEZE           = 2;
    /** 解冻 */
    public static final int   UNFREEZE         = 3;

    /** 审核的账号id */
    private Long              accountId;
    /** 审核动作类型,0-审核通过;1-审核拒绝;2-冻结;3-解冻 */
    private Integer               checkType;
    /** 拒绝或冻结理由 */
    private String            reason;
    /** 广告顾问 */
    private String            checker;
    /** 广告顾问联系方式 */
    private String            checkerContact;

    /**
     * accountId.
     *
     * @return  the accountId
     * @since   JDK 1.8
     */
    public Long getAccountId() {
        return accountId;
    }
    
    /**
     * accountId.
     *
     * @param   accountId    the accountId to set
     * @since   JDK 1.8
     */
    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }
    
    /**
     * checkType.
     *
     * @return  the checkType
     * @since   JDK 1.8
     */
    public Integer getCheckType() {
        return checkType;
    }

    /**
     * checkType.
     *
     * @param   checkType    the checkType to set
     * @since   JDK 1.8
     */
    public void setCheckType(Integer checkType) {
        this.checkType = checkType;
    }

    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }

    public String getChecker() {
        return checker;
    }

    public void setChecker(String checker) {
        this.checker = checker;
    }

    public String getCheckerContact() {
        return checkerContact;
    }

    public void setCheckerContact(String checkerContact) {
        this.checkerContact = checkerContact;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

}

==> tuia-advert-center-api-2.2.78-sources.jar: cn/com/duiba/tuia/core/api/dto/AccountCheckRecordDto.java <==
/**
 * 文件名： AccountCheckRecordDO.java 此类描述的是： 作者: sunjiangrong 创建时间: 2016年4月7日 下午3:19:01
 */
package cn.com.duiba.tuia.core.api.dto;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * <一句话功能描述> <功能详细描述>
 *
 * @author: sunjiangrong
 * @创建时间: 2016年4月7日 下午3:19:01
 * @version:
 */
public class AccountCheckRecordDto extends BaseDto {

    private static final long serialVersionUID = 5143933030739357226L;

    /**
     * 审核通过
     */
    public static final int CHECK_PASS = 0;
    /**
     * 审核不通过
     */
    public static final int CHECK_REFUSE = 1;
    /**
     * 冻结
     */
    public static final int FREEZE = 2;
    /**
     * 解冻
     */
    public static final int UNFREEZE = 3;

    /**
     * 审核的账号id
     */
    private Long accountId;
    /**
     * 审核动作类型,0-审核通过;1-审核拒绝;2-冻结;3-解冻
     */
    private Integer checkType;
    /**
     * 拒绝或冻结理由
     */
    private String reason;
    /**
     * 广告顾问
     */
    private String checker;
    /**
     * 广告顾问联系方式
     */
    private String checkerContact;
    /**
     * 审核人.
     */
    private String reviewer;

    /**
     * accountId.
     *
     * @return the accountId
     * @since JDK 1.8
     */
    public Long getAccountId() {
        return accountId;
    }

    /**
     * accountId.
     *
     * @param accountId the accountId to set
     * @since JDK 1.8
     */
    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    /**
     * checkType.
     *
     * @return the checkType
     * @since JDK 1.8
     */
    public Integer getCheckType() {
        return checkType;
    }

    /**
     * checkType.
     *
     * @param checkType the checkType to set
     * @since JDK 1.8
     */
    public void setCheckType(Integer checkType) {
        this.checkType = checkType;
    }

    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }

    public String getChecker() {
        return checker;
    }

    public void setChecker(String checker) {
        this.checker = checker;
    }

    public String getCheckerContact() {
        return checkerContact;
    }

    public void setCheckerContact(String checkerContact) {
        this.checkerContact = checkerContact;
    }

    public String getReviewer() {
        return reviewer;
    }

    public void setReviewer(String reviewer) {
        this.reviewer = reviewer;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

}
